@@ -1,5 +1,5 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
-from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES, Types
+from ...mappings import Types
 from graphene import Field, List, ObjectType
 from ...resolvers.field import build_field_resolver
 from ...resolvers.list import build_list_resolver
@@ -15,7 +15,7 @@ class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
         entity_class = registry.get_entity_class(model_class)
 
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
 
             if (
                 field.is_relation
@@ -25,10 +25,7 @@ class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
 
             # Handle concrete, non-relation fields
             if not field.is_relation:
-                type_name = field.get_internal_type()
-                graphene_type = model_field.get_graphene_type(
-                    model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
-                )
+                graphene_type = registry.get_graphene_type_or_default(model_field)
 
                 # Enum/choice fields are handled as special cases
                 if field.choices:
@@ -64,8 +61,8 @@ class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                         field.related_model
                     )[get_target_field(field).name]
 
-                    graphene_type = reverse_model_field.get_graphene_type(
-                        field.related_model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                    graphene_type = registry.get_graphene_type_or_default(
+                        reverse_model_field
                     )
                     basic_type_attrs["{}_id".format(field.name)] = graphene_type(
                         required=not field.null
@@ -98,10 +95,7 @@ class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
 
         # Add computed (property) fields defined on the Entity class
         for computed_field in entity_class._get_computed_fields():
-            graphene_type = computed_field.get_graphene_type(
-                model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
-            )
-            basic_type_attrs[computed_field.name] = graphene_type()
+            basic_type_attrs[computed_field.name] = computed_field.graphene_type()
             resolver = computed_field.get_resolver(entity_class)
             basic_type_attrs[
                 "resolve_{}".format(computed_field.name)
