@@ -1,6 +1,6 @@
 from djraphql.util.django_models import get_target_field
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
-from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES, Types
+from ...mappings import Types
 from graphene import Field, InputObjectType, List
 
 
@@ -15,7 +15,7 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
         entity_class = registry.get_entity_class(model_class)
 
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
 
             if (field.concrete and field.primary_key) or model_field.read_only:
                 continue
@@ -41,8 +41,8 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                         field.related_model
                     )[get_target_field(field).name]
 
-                    graphene_type = reverse_model_field.get_graphene_type(
-                        field.related_model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                    graphene_type = registry.get_graphene_type_or_default(
+                        reverse_model_field
                     )
                     input_class_attrs["{}_id".format(field.name)] = graphene_type()
 
@@ -67,8 +67,8 @@ class InsertInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                     enum_type, required=not field.null and field.default is None
                 )
             else:
-                input_class_attrs[field.name] = model_field.get_graphene_type(
-                    model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                input_class_attrs[field.name] = registry.get_graphene_type_or_default(
+                    model_field
                 )(required=not field.null and not field.has_default())
 
         return type(
