@@ -1,6 +1,6 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import List, InputObjectType, Boolean, Field
-from ...mappings import Types, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+from ...mappings import Types
 
 
 class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -12,7 +12,7 @@ class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
         # Build where predicate InputObjects to allow filtering in queries.
         where_input_type_attrs = {}
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
 
             if field.is_relation:
                 if field.many_to_one or field.one_to_many:
@@ -59,9 +59,7 @@ class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
                     },
                 )()
             else:
-                graphene_type = model_field.get_graphene_type(
-                    model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
-                )
+                graphene_type = registry.get_graphene_type_or_default(model_field)
                 where_input_type_attrs[field_name] = registry.get_or_create_type(
                     Types.WHERE_PREDICATE_INPUT_TYPE,
                     graphene_type=graphene_type,
