@@ -8,16 +8,17 @@ class TypeRegistry:
 
     def __init__(self, schema):
         self.schema = schema
-        self._schema_builder_mapping = schema.get_builder_mapping()
         self._node_graphql_type_name_to_model_class = {}
         self._cache = {
             "models": {},
             "types": {},
         }
 
-    @property
-    def available_model_classes(self):
-        return self._model_cache.keys()
+    def get_available_model_classes(self):
+        if not hasattr(self, "_available_model_classes"):
+            self._get_available_model_classes = self._model_cache.keys()
+
+        return self._get_available_model_classes
 
     @property
     def _model_cache(self):
@@ -31,7 +32,7 @@ class TypeRegistry:
         return self._model_cache.get(model_class, {}).get(self._ENTITY_CLASS_KEY)
 
     def get_builder_class(self, type_key):
-        return self._schema_builder_mapping[type_key]
+        return self.schema.BUILDER_MAP[type_key]
 
     def lambda_from_registry(self, model_class, key):
         def _get_type_from_registry():
@@ -66,7 +67,7 @@ class TypeRegistry:
             }
 
     def get_or_create_type(self, type_key, **kwargs):
-        if type_key not in self._schema_builder_mapping:
+        if type_key not in self.schema.BUILDER_MAP:
             raise Exception(
                 "get_or_create_type called with unknown key: {}".format(type_key)
             )
@@ -88,10 +89,10 @@ class TypeRegistry:
             return self._model_cache[model_class].get(self._MODEL_FIELDS_KEY)
 
         result = {}
-        entity_class = self._model_cache[model_class][self._ENTITY_CLASS_KEY]
-        available_model_classes = self.available_model_classes
+        entity_class = self.get_entity_class(model_class)
+        available_model_classes = self.get_available_model_classes()
         for model_field in entity_class.get_all_model_fields():
-            django_model_field = model_field.get_django_model_field(model_class)
+            django_model_field = model_field.get_django_model_field()
             if (
                 not django_model_field.is_relation
                 or django_model_field.related_model in available_model_classes
@@ -102,4 +103,13 @@ class TypeRegistry:
         return result
 
     def get_pk_fields_for_model(self, model_class):
-        return get_pk_fields_for_model(model_class, self.available_model_classes)
+        return get_pk_fields_for_model(model_class, self.get_available_model_classes())
+
+    def get_graphene_type_or_default(self, model_field):
+        # If the ModelField specifies its desire graphene_type, use it
+        if model_field.graphene_type:
+            return model_field.graphene_type
+
+        # Otherwise, fall back to the type map used by the generation schema
+        field = model_field.get_django_model_field()
+        return self.schema.FIELD_TYPE_MAP[field.get_internal_type()]
